module.exports = defineTest({
	description: 'does not consider tree-shaken variables when deconflicting'
});
